# API Documentation

```{eval-rst}
.. currentmodule:: sortedl1
```

## Estimators

These are all the estimators in the package. They are all derived from scikit-learn classes and use the same API. Each of the estimators represent a different objective function, but all use the same penalty term (the sorted l-one norm).

```{eval-rst}
.. currentmodule:: sortedl1

.. autosummary::
   :toctree: generated
   :template: class.rst

    Slope
```
